# frozen_string_literal: true

class BasicObject
  #  Used by `sr` to allow the same general access to `BasicObject` instances
  #  that `Object#__binding__` permits for all other objects.
  #
  # @return [Binding] an unclean `Binding` instance representing the current
  #   binding of this object
  def __binding__
    (class << self ; self end).class_eval <<-END
      def __fallback_binding__
        ::Kernel.binding
      end
    END
    self.__fallback_binding__
  end

  # @return [String] a simple inspection string
  def inspect
    '#<BasicObject>'
  end
  alias_method :to_s, :inspect
end

class Object
  # Used extensively by `sr` -- this method is essentially what allows
  # interactive code to reach into the state of objects at runtime.
  #
  # @return [Binding] a clean `Binding` instance representing the current
  #   binding of this object
  def __binding__
    is_a?(Module) ? class_eval('binding') : binding
  end
end

module Kernel
  # @return [Binding] the top level binding
  def main
    TOPLEVEL_BINDING
  end
end

class << TOPLEVEL_BINDING
  # @note this method exists entirely for aesthetic purposes (when the default
  #   input prompt calls `@context.receiver` to get a name for the current
  #   binding/context)
  # @return [String] a simple inspection string
  def to_s
    'main'
  end
end
